<?php declare(strict_types=1);
/**
 * Helper class for using Twig templates
 */

namespace Infomaker\Everyware\Twig;

use Infomaker\Everyware\Support\NewRelicLog;
use Infomaker\Everyware\Support\Str;
use Twig_Error;

/**
 * View
 *
 * @link    http://infomaker.se
 * @package Infomaker\Everyware\Twig
 * @since   Infomaker\Everyware\Twig\View 0.1
 */
class View
{
    /**
     * Render template with context data
     *
     * @param string $template
     * @param array  $context
     *
     * @return void
     */
    public static function render(string $template, array $context = []): void
    {
        $everyTwig = ViewSetup::getInstance()->getEveryTwig();

        $templateFile = Str::finish($template, '.twig');

        try {
            $everyTwig->render($templateFile, $context);
        } catch (Twig_Error $e) {
            NewRelicLog::error("Failed to render twig-template: {$templateFile}. ", $e);
        }
    }

    /**
     * Generate a HTML-version of the template with context data
     *
     * @param string $template
     * @param array  $context
     *
     * @return string
     */
    public static function generate(string $template, array $context = []): string
    {
        $everyTwig = ViewSetup::getInstance()->getEveryTwig();
        $templateFile = Str::finish($template, '.twig');

        try {
            return $everyTwig->view($templateFile, $context);
        } catch (Twig_Error $e) {
            NewRelicLog::error("Failed to generate twig-template: {$templateFile}. ", $e);
        }
    }
}
